using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Drawing.Text;
using System.Windows.Forms;
using Steema.TeeChart;
using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;

namespace WindowsApplication1
{
    public partial class Form1 : Form
    {
        private Steema.TeeChart.Functions.Cumulative cum1;
        private Steema.TeeChart.Styles.Line line1;
        private Steema.TeeChart.Styles.Bar bar1;
        private SortedDictionary<DateTime, int> dict = new SortedDictionary<DateTime, int>();

        public Form1()
        {
            InitializeComponent();
            InitializeChart();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            SetupChart();
            CreateDataSet();

            bar1 = new Bar(tChart1.Chart);
            bar1.Marks.Visible = false;
            bar1.ShowInLegend = false;
            bar1.Active = true;

            foreach (KeyValuePair<DateTime, int> pair in dict)
            {
                bar1.Add(pair.Key.Date, pair.Value);
            }

            line1 = new Line(tChart1.Chart);
            line1.Color = Color.LightGray;
            line1.LinePen.Width = 1;
            line1.XValues.DateTime = true;
            line1.Pointer.VertSize = 1;
            line1.Pointer.HorizSize = 3;
            line1.Pointer.Pen.Color = Color.LightSkyBlue;
            line1.Pointer.Brush.Color = Color.LightSkyBlue;
            line1.Pointer.Visible = true;

            cum1 = new Steema.TeeChart.Functions.Cumulative(tChart1.Chart);
            cum1.PeriodAlign = Steema.TeeChart.Functions.PeriodAligns.First;
            cum1.PeriodStyle = Steema.TeeChart.Functions.PeriodStyles.Range;
            cum1.Period = 12;

            line1.DataSource = bar1;
            line1.Function = cum1;
            line1.CheckDataSource();
        }

        private void SetupChart()
        {
            // Set properties for this type of chart
            tChart1.Axes.Visible = true;

            tChart1.Axes.Left.AxisPen.Visible = false;
            tChart1.Axes.Left.AxisPen.Width = 1;
            tChart1.Axes.Left.Increment = 1;
            tChart1.Axes.Left.Minimum = 0;
            tChart1.Axes.Left.Title.Text = "Cumulative Rainfall";
            tChart1.Axes.Left.Title.Font.Color = Color.Black;
            tChart1.Axes.Left.Title.Font.Size = 8;
            tChart1.Axes.Left.Labels.Font.Color = Color.Black;
            tChart1.Axes.Left.Labels.Font.Size = 8;
            tChart1.Axes.Left.Labels.OnAxis = true;
            tChart1.Axes.Left.Labels.Visible = true;
            tChart1.Axes.Left.Grid.Visible = false;

            tChart1.Axes.Bottom.AxisPen.Visible = true;
            tChart1.Axes.Bottom.AxisPen.Width = 1;
            tChart1.Axes.Bottom.Title.Font.Color = Color.Black;
            tChart1.Axes.Bottom.Title.Font.Size = 8;
            tChart1.Axes.Bottom.Labels.Font.Color = Color.Black;
            tChart1.Axes.Bottom.Labels.Font.Name = "Arial";
            tChart1.Axes.Bottom.Labels.Font.Size = 8;
            tChart1.Axes.Bottom.Labels.Angle = 90;
            tChart1.Axes.Bottom.Labels.Visible = true;
            tChart1.Axes.Bottom.Labels.Style = Steema.TeeChart.AxisLabelStyle.Value;
            tChart1.Axes.Bottom.Increment = Steema.TeeChart.Utils.GetDateTimeStep(Steema.TeeChart.DateTimeSteps.OneMonth);
            tChart1.Axes.Bottom.MinorTicks.Visible = true;
            tChart1.Axes.Bottom.MinimumOffset = 1;
            tChart1.Axes.Bottom.MinorGrid.Visible = false;
            tChart1.Axes.Bottom.Grid.Visible = false;
        }

        private void CreateDataSet()
        {
            // Hydrological Year 1
            dict.Add(Convert.ToDateTime("1984-10-01"), 5);
            dict.Add(Convert.ToDateTime("1984-11-01"), 7);
            dict.Add(Convert.ToDateTime("1984-12-01"), 4);
            dict.Add(Convert.ToDateTime("1985-01-01"), 8);
            dict.Add(Convert.ToDateTime("1985-02-01"), 2);
            dict.Add(Convert.ToDateTime("1985-03-01"), 6);
            dict.Add(Convert.ToDateTime("1985-04-01"), 1);
            dict.Add(Convert.ToDateTime("1985-05-01"), 4);
            dict.Add(Convert.ToDateTime("1985-06-01"), 6);
            dict.Add(Convert.ToDateTime("1985-07-01"), 3);
            dict.Add(Convert.ToDateTime("1985-08-01"), 9);
            dict.Add(Convert.ToDateTime("1985-09-01"), 1);

            // Hydrological Year 2
            dict.Add(Convert.ToDateTime("1985-10-01"), 5);
            dict.Add(Convert.ToDateTime("1985-11-01"), 7);
            dict.Add(Convert.ToDateTime("1985-12-01"), 4);
            dict.Add(Convert.ToDateTime("1986-01-01"), 8);
            dict.Add(Convert.ToDateTime("1986-02-01"), 2);
            dict.Add(Convert.ToDateTime("1986-03-01"), 6);
            dict.Add(Convert.ToDateTime("1986-04-01"), 1);
            dict.Add(Convert.ToDateTime("1986-05-01"), 4);
            dict.Add(Convert.ToDateTime("1986-06-01"), 6);
            dict.Add(Convert.ToDateTime("1986-07-01"), 3);
            dict.Add(Convert.ToDateTime("1986-08-01"), 9);
            dict.Add(Convert.ToDateTime("1986-09-01"), 1);
        }

        private void InitializeChart()
        {
            #region Init
            tChart1.Panel.Bevel.ColorOne = Color.FromArgb(101, 147, 207);
            tChart1.Panel.Bevel.ColorTwo = Color.FromArgb(101, 147, 207);
            tChart1.Panel.Bevel.Outer = BevelStyles.Lowered;
            tChart1.Aspect.SmoothingMode = SmoothingMode.HighQuality;
            tChart1.Aspect.TextRenderingHint = TextRenderingHint.ClearTypeGridFit;
            tChart1.Aspect.View3D = false;
            tChart1.Aspect.ZOffset = 0;
            tChart1.Axes.Bottom.Automatic = true;
            tChart1.Axes.Bottom.AutomaticMaximum = true;
            tChart1.Axes.Bottom.AutomaticMinimum = true;
            tChart1.Axes.Bottom.AxisPen.Visible = true;
            tChart1.Axes.Bottom.Grid.Visible = true;
            tChart1.Axes.Bottom.Increment = 0;
            tChart1.Axes.Bottom.Labels.Items.Clear();
            tChart1.Axes.Bottom.Labels.Angle = 0;
            tChart1.Axes.Bottom.Logarithmic = false;
            tChart1.Axes.Bottom.Maximum = 0;
            tChart1.Axes.Bottom.MaximumOffset = 0;
            tChart1.Axes.Bottom.Minimum = 0;
            tChart1.Axes.Bottom.MinimumOffset = 0;
            tChart1.Axes.Bottom.MinorTicks.Visible = true;
            tChart1.Axes.Bottom.Title.Text = string.Empty;
            tChart1.Axes.Custom.Clear();
            tChart1.Axes.Custom.RemoveAll();
            tChart1.Axes.Left.Automatic = true;
            tChart1.Axes.Left.AutomaticMaximum = true;
            tChart1.Axes.Left.AutomaticMinimum = true;
            tChart1.Axes.Left.AxisPen.Visible = true;
            tChart1.Axes.Left.Increment = 0;
            tChart1.Axes.Left.Logarithmic = false;
            tChart1.Axes.Left.Maximum = 0;
            tChart1.Axes.Left.MaximumOffset = 0;
            tChart1.Axes.Left.Minimum = 0;
            tChart1.Axes.Left.MinimumOffset = 0;
            tChart1.Axes.Left.MinorTickCount = 3;
            tChart1.Axes.Left.StartPosition = 0; tChart1.Axes.Left.EndPosition = 100;
            tChart1.Axes.Left.Title.Text = string.Empty;
            tChart1.Axes.Right.Automatic = true;
            tChart1.Axes.Right.AutomaticMaximum = true;
            tChart1.Axes.Right.AutomaticMinimum = true;
            tChart1.Axes.Right.AxisPen.Visible = true;
            tChart1.Axes.Right.Increment = 0;
            tChart1.Axes.Right.Logarithmic = false;
            tChart1.Axes.Right.Maximum = 0;
            tChart1.Axes.Right.MaximumOffset = 0;
            tChart1.Axes.Right.Minimum = 0;
            tChart1.Axes.Right.MinimumOffset = 0;
            tChart1.Axes.Right.MinorTickCount = 3;
            tChart1.Axes.Right.StartPosition = 0; tChart1.Axes.Left.EndPosition = 100;
            tChart1.Axes.Right.Title.Text = string.Empty;
            tChart1.Axes.Visible = false;
            tChart1.BackColor = Color.White;
            tChart1.Header.Font.Color = Color.Black;
            tChart1.Header.Font.Size = 10;
            tChart1.Legend.Alignment = LegendAlignments.Right;
            tChart1.Legend.Pen.Color = Color.Black;
            tChart1.Legend.CheckBoxes = true;
            tChart1.Legend.Color = Color.Transparent;
            tChart1.Legend.Font.Color = Color.Black;
            tChart1.Legend.Font.Size = 8;
            tChart1.Legend.Shadow.Visible = false;
            tChart1.Legend.Visible = true;
            tChart1.Panel.Gradient.Visible = false;
            tChart1.Panning.Allow = ScrollModes.None;
            tChart1.Printer.UseAntiAlias = true;
            tChart1.Series.Clear();
            tChart1.SubHeader.Font.Color = Color.Black;
            tChart1.SubHeader.Font.Size = 10;
            tChart1.SubHeader.Visible = true;
            tChart1.Walls.View3D = false;
            tChart1.Walls.Visible = false;
            tChart1.Walls.Back.Gradient.StartColor = Color.White;
            tChart1.Walls.Back.Gradient.EndColor = Color.White;
            tChart1.Zoom.Allow = false;
            #endregion
        }
    }
}